ossp-pkg/rc/rc_private.h 1.7 -> 1.8
--- rc_private.h 2002/03/26 17:11:06 1.7
+++ rc_private.h 2002/04/08 15:37:10 1.8
@@ -60,12 +60,10 @@
((rv) != RC_OK && (ex_catching && !ex_shielding) \
? (ex_throw(RC_STR_ID, NULL, (rv)), (rv)) : (rv))
-#include "val.h"
-
typedef struct { /* Main rc configuration storage */
- val_t *pOpt; /* Storage of configuration values */
- int nLocks; /* Server locks, not thread-safe though */
+ void *pvFixme; /* Storage of configuration values */
+ int nLocks; /* Server locks, not thread-safe FIXME */
} rc_config_t;
#endif /* __OSSPRC_PRIVATE_H__ */
|
|